# Table of Contents

- [landscape-report](<./landscape-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Landscape Report](<./Landscape-Report.md>)
  - [HOW is it useful?](<./Landscape-Report/HOW-is-it-useful.md>)
  - [Using Drill-Down](<./Landscape-Report/Using-Drill-Down.md>)
  - [Applying Views to Drilled-Down Fact Sheets](<./Landscape-Report/Applying-Views-to-Drilled-Down-Fact-Sheets.md>)
  - [Understanding Views for Fields on Related Fact Sheets](<./Landscape-Report/Understanding-Views-for-Fields-on-Related-Fact-Sheets.md>)
  - [Freezing Cluster Headers](<./Landscape-Report/Freezing-Cluster-Headers.md>)
  - [Editing in Landscape Report](<./Landscape-Report/Editing-in-Landscape-Report.md>)
  - [Tags](<./Landscape-Report/Tags.md>)
  - [Relations](<./Landscape-Report/Relations.md>)
  - [Attributes](<./Landscape-Report/Attributes.md>)
  - [Layout Modes](<./Landscape-Report/Layout-Modes.md>)
  - [Differential view](<./Landscape-Report/Differential-view.md>)
  - [Was this page helpful?](<./Landscape-Report/Was-this-page-helpful.md>)
